@@ -60,17 +60,17 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.27.48-0.2.1.src.rpm ]
+if [ ! -r kernel-source-2.6.27.56-0.1.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.1/rpm/src/kernel-source-2.6.27.48-0.2.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.1/rpm/src/kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-2.6.27.48-0.2.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-2.6.27.48-0.2.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.27.56-0.1.1.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100923.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20110121.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100923.tar.gz || die "Can't download patch."
+    wget -O ccs-patch-1.7.2-20110121.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20110121.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -89,9 +89,9 @@ patch << "EOF" || die "Can't patch spec file."
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        2.6.27.48
--Release:        0.2.1
-+Release:        0.2.1_tomoyo_1.7.2p3
+ Version:        2.6.27.56
+-Release:        0.1.1
++Release:        0.1.1_tomoyo_1.7.2p4
  License:        GPL v2 only
  Group:          System/Kernel
  Url:            http://www.kernel.org/
@@ -109,7 +109,7 @@ patch << "EOF" || die "Can't patch spec file."
  
  cd linux-2.6.27
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100923.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20110121.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.27-suse-11.1.diff
 +cat config.ccs >> .config
  cp .config .config.orig
