@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/audit.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.2+   2011/01/21
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -218,7 +218,7 @@ static char *ccs_print_header(struct ccs_request_info *r)
 				" path1.parent={ uid=%u gid=%u ino=%lu"
 				" perm=0%o }", obj->path1_parent_stat.uid,
 				obj->path1_parent_stat.gid,
-				obj->path1_parent_stat.ino,
+				(unsigned long) obj->path1_parent_stat.ino,
 				obj->path1_parent_stat.mode & S_IALLUGO);
 	}
 	if (obj->path2_valid) {
@@ -244,7 +244,7 @@ static char *ccs_print_header(struct ccs_request_info *r)
 				" path2.parent={ uid=%u gid=%u ino=%lu"
 				" perm=0%o }", obj->path2_parent_stat.uid,
 				obj->path2_parent_stat.gid,
-				obj->path2_parent_stat.ino,
+				(unsigned long) obj->path2_parent_stat.ino,
 				obj->path2_parent_stat.mode & S_IALLUGO);
 	}
  no_obj_info:
@@ -275,10 +275,7 @@ char *ccs_init_audit_log(int *len, struct ccs_request_info *r)
 	const char *symlink = NULL;
 	const char *header = NULL;
 	int pos;
-	const char *domainname;
-	if (!r->domain)
-		r->domain = ccs_current_domain();
-	domainname = r->domain->domainname->name;
+	const char *domainname = ccs_current_domain()->domainname->name;
 	header = ccs_print_header(r);
 	if (!header)
 		return NULL;
@@ -414,10 +411,8 @@ int ccs_write_audit_log(const bool is_granted, struct ccs_request_info *r,
 	char *buf;
 	struct ccs_audit_log_entry *new_entry;
 	bool quota_exceeded = false;
-	struct ccs_preference *pref;
-	if (!r->domain)
-		r->domain = ccs_current_domain();
-	pref = ccs_profile(r->domain->profile)->audit;
+	struct ccs_preference *pref =
+		ccs_profile(ccs_current_domain()->profile)->audit;
 	if (is_granted)
 		len = pref->audit_max_grant_log;
 	else
