@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/file.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.7.2+   2010/09/18
+ * Version: 1.7.2+   2011/01/21
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -30,6 +30,12 @@
 #define ACC_MODE(x) ("\000\004\002\006"[(x)&O_ACCMODE])
 #endif
 
+#if defined(RHEL_MAJOR) && RHEL_MAJOR == 6
+/* However, RHEL6 passes unmodified flags since 2.6.32-71.14.1.el6 . */
+#undef ACC_MODE
+#define ACC_MODE(x) ("\004\002\006"[(x)&O_ACCMODE])
+#endif
+
 static const char *ccs_path_keyword[CCS_MAX_PATH_OPERATION] = {
 	[CCS_TYPE_READ_WRITE] = "read/write",
 	[CCS_TYPE_EXECUTE]    = "execute",
